/*
 * Copyright (c) 1998, Wolfram Schneider <schneider@zib.de>,
 *                     Konrad Zuse Zentrum fr Informationstechnik Berlin.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *  $Id: ansellat1.l,v 1.2 1998/02/26 17:57:38 wolfram Exp $
 *
 *
 * 8-Bit ANSEL to ISO8859-1 conversion. This file support only a subset
 * of Z39.47-1993 (ANSEL). It is incomplete due the lack of free
 * available documentation ;-(
 *
 * http://www.niso.org/pccodes.htm
 * Z39.47-1993 Extended Latin Alphabet Coded Character Set for
 * Bibliographic Use (ANSEL)
 * 
 * Character sets are a basic building block of automated information
 * systems. Z39.47 provides a table of coded values for the
 * representation of characters of the extended Latin alphabet in
 * machine-readable form for thirty-five languages written in the Latin
 * alphabet and for fifty-one romanized languages.
 * 
 * 27 pp. ISBN: 1-880124-02-5 Price: $40.00 
 * 
 *
 * http://wwnet.com/~krugman1/gentext/gedstand.txt
 * 8-Bit ANSEL
 * 
 * The 8-Bit ANSEL (American National Standard for Extended Latin
 * Alphabet Coded Character Set for Bibliographic Use, Z39.47, 1985
 * copyright) is the default character set for GEDCOM. [...]
 * The ANSEL standard
 * specifies an extended 8-bit configuration (above 128) to represent the
 * spacing and non-spacing graphic characters that make up most of the
 * Latin based languages.  ANSEL is a super-set of ASCII.  The standard
 * ASCII characters including the control characters are preserved.
 * 
 * ANSEL is known by two other names: (1) ANSI Z39.47-1985) and (2) the
 * American Library Association character set, used in library systems
 * worldwide, including the MARC (MAchine- Readable Catalog) format.
 * 
 * A description of the codes for the ANSEL character set has been
 * reproduced with permission and is included with the printed version of
 * The GEDCOM Standard. The description of ANSEL codes is not included in
 * the electronic version.  This description may be purchased from the
 * American National Standards Institute at 1430 Broadway, New York,
 * N.Y. 10018.  The description of the ANSEL character set standard
 * includes the following:
 * 
 *     *       An 8-Bit Code Table showing the ASCII and extended ANSEL codes
 *     *       An explanation or legend of these codes
 *     *       A chart that identifies the ANSEL Non-spacing Graphic Characters
 *     *       A chart that identifies the ASCII Control Characters
 *     *       A chart that identifies the ASCII Graphic Characters
 * 
 * Character-set codes 0 through 127 are the same for 8-Bit ANSEL and
 * 8-Bit ASCII (USA version-- ANSI 8-Bit). Character-set codes 128
 * through 255 are unique to the ANSEL character set.
 * 
 */


/* Step name: ansel_latin1.  */

%%

\241 { output(76); }
\242 { output(79); }
\243 { output(68); }
\244 { output(222); }
\245 { output(198); }
\246 { output(216); }

\253 { output(177); }


\261 { output(108); }
\262 { output(248); }
\263 { output(100); }

\265 { output(230); }
\266 { output(111); }

\271 { output(163); }
\272 { output(240); }


\303 { output(169); }
\340 { output(191); }
\341A { output(192); }
\341E { output(200); }
\341I { output(204); }
\341O { output(210); }
\341U { output(217); }
\341a { output(224); }
\341e { output(232); }
\341i { output(236); }
\341o { output(242); }
\341u { output(249); }

\342A { output(193); }
\342E { output(201); }
\342I { output(205); }
\342O { output(211); }
\342U { output(218); }

\342a { output(225); }
\342e { output(233); }
\342i { output(237); }
\342o { output(243); }
\342u { output(250); }
\342y { output(253); }

\343A { output(194); }
\343E { output(202); }
\343I { output(206); }
\343O { output(212); }
\343U { output(219); }

\343a { output(226); }
\343e { output(234); }
\343i { output(238); }
\343o { output(244); }
\343u { output(251); }

\344A { output(195); }
\344O { output(213); }
\344N { output(209); }
\344a { output(227); }
\344o { output(245); }
\344n { output(241); }

\345  { output(175); }

\350A { output(196); }
\350E { output(203); }
\350I { output(207); }
\350O { output(214); }
\350U { output(220); }

\350a { output(228); }
\350e { output(235); }
\350i { output(239); }
\350o { output(246); }
\350u { output(252); }
\350y { output(255); }

\352A { output(197); }
\352a { output(229); }


%%

void
module_ansel_latin1 (void)
{
  declare_step ("Z39.47:1993", "latin1", MANY_TO_ONE, NULL, file_ansel_latin1);
  declare_alias ("8bitANSEL", "Z39.47:1993");
  declare_alias ("Z39.47", "Z39.47:1993");
  declare_alias ("ANSEL", "Z39.47:1993");
  declare_alias ("USMARC", "Z39.47:1993");
  declare_alias ("MARC", "Z39.47:1993");
  declare_alias ("LOC", "Z39.47:1993"); /* Library of Congress */
}

